==> haskell-ghc-mod-5.7.0.0-29-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ghc-mod.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ghc-mod
version: 5.7.0.0
id: ghc-mod-5.7.0.0-4WmaTrWN7PL96JuZyjfjRk
key: ghc-mod-5.7.0.0-4WmaTrWN7PL96JuZyjfjRk
license: AGPL-3
maintainer: Daniel Gröber <dxld@darkboxed.org>
homepage: http://www.mew.org/~kazu/proj/ghc-mod/
synopsis: Happy Haskell Programming
description:
    ghc-mod is a backend program to enrich Haskell programming in editors. It
    strives to offer most of the features one has come to expect from modern IDEs
    in any editor.
    ghc-mod provides a library for other haskell programs to use as well as a
    standalone program for easy editor integration. All of the fundamental
    functionality of the frontend program can be accessed through the library
    however many implementation details are hidden and if you want to
    significantly extend ghc-mod you should submit these changes upstream instead
    of implementing them on top of the library.
    For more information, please see its home page.
category: GHC, Development
author: Kazu Yamamoto <kazu@iij.ad.jp>,
        Daniel Gröber <dxld@darkboxed.org>,
        Alejandro Serrano <trupill@gmail.com>,
        Nikolay Yakimov <root@livid.pp.ru>
exposed: True
exposed-modules:
    Language.Haskell.GhcMod Language.Haskell.GhcMod.Internal
    Language.Haskell.GhcMod.Boot Language.Haskell.GhcMod.Browse
    Language.Haskell.GhcMod.CabalHelper Language.Haskell.GhcMod.Caching
    Language.Haskell.GhcMod.Caching.Types
    Language.Haskell.GhcMod.CaseSplit Language.Haskell.GhcMod.Check
    Language.Haskell.GhcMod.Convert Language.Haskell.GhcMod.Cradle
    Language.Haskell.GhcMod.CustomPackageDb
    Language.Haskell.GhcMod.Debug Language.Haskell.GhcMod.DebugLogger
    Language.Haskell.GhcMod.Doc Language.Haskell.GhcMod.DynFlags
    Language.Haskell.GhcMod.DynFlagsTH Language.Haskell.GhcMod.Error
    Language.Haskell.GhcMod.FileMapping Language.Haskell.GhcMod.FillSig
    Language.Haskell.GhcMod.Find Language.Haskell.GhcMod.Flag
    Language.Haskell.GhcMod.Gap Language.Haskell.GhcMod.GhcPkg
    Language.Haskell.GhcMod.HomeModuleGraph
    Language.Haskell.GhcMod.Info Language.Haskell.GhcMod.Lang
    Language.Haskell.GhcMod.Lint Language.Haskell.GhcMod.LightGhc
    Language.Haskell.GhcMod.Logger Language.Haskell.GhcMod.Logging
    Language.Haskell.GhcMod.Modules Language.Haskell.GhcMod.Monad
    Language.Haskell.GhcMod.Monad.Env Language.Haskell.GhcMod.Monad.Log
    Language.Haskell.GhcMod.Monad.Newtypes
    Language.Haskell.GhcMod.Monad.Orphans
    Language.Haskell.GhcMod.Monad.Out
    Language.Haskell.GhcMod.Monad.State
    Language.Haskell.GhcMod.Monad.Types Language.Haskell.GhcMod.Output
    Language.Haskell.GhcMod.PathsAndFiles
    Language.Haskell.GhcMod.PkgDoc Language.Haskell.GhcMod.Pretty
    Language.Haskell.GhcMod.Read Language.Haskell.GhcMod.SrcUtils
    Language.Haskell.GhcMod.Stack Language.Haskell.GhcMod.Target
    Language.Haskell.GhcMod.Test Language.Haskell.GhcMod.Types
    Language.Haskell.GhcMod.Utils Language.Haskell.GhcMod.World
    Language.Haskell.GhcMod.Options.Options
    Language.Haskell.GhcMod.Options.DocUtils
    Language.Haskell.GhcMod.Options.Help
hidden-modules: Paths_ghc_mod Utils Data.Binary.Generic
                System.Directory.ModTime
abi: 97f3ea91c2aaf099acf4a6b8a60bd751
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/ghc-mod-5.7.0.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/ghc-mod-5.7.0.0
data-dir: /usr/share/ghc-mod
hs-libraries: HSghc-mod-5.7.0.0-4WmaTrWN7PL96JuZyjfjRk
depends:
    base-4.9.0.0 binary-0.8.3.0 bytestring-0.10.8.1
    cabal-helper-0.7.3.0-8irtsA9yeTTAn5BCqOpvck containers-0.5.7.1
    deepseq-1.4.2.0 directory-1.2.6.2
    djinn-ghc-0.0.2.3-JYPrGjYjGTkHuXWB4dLmHD
    extra-1.5.2-FWjov7JFxoq2wD5IPaMEgG
    fclabels-2.0.3.2-3Xs3bCBbAC9J1XqCJSoYEp filepath-1.4.1.0 ghc-8.0.1
    ghc-boot-8.0.1 ghc-paths-0.1.0.9-GIOnKzk0HmEBZ77Q1HsThK
    ghc-syb-utils-0.2.3-8FwTENlrnJNLAYazvnOvfZ
    haskell-src-exts-1.18.2-HHC3x3A3NPPIRZVmSBLAjX
    hlint-1.9.41-HBcsScTizwhGFuSoasdklT
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    monad-journal-0.7.2-LdzJ97MJz5972dk8ynYKRG
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    old-time-1.1.0.3-IcvdkJUsE9M8t3io8peAEp
    optparse-applicative-0.13.2.0-403Af4vaGHEIyn0ZdeZhZL
    pipes-4.3.3-DUMcfIYjM5M3cknwPI4AKY pretty-1.1.3.3 process-1.4.2.0
    safe-0.3.14-ALdwhNEer7fKnF5VYCbXfH
    split-0.2.3.1-IJKK4pOCYGKud0jZImZke syb-0.6-C65vWCsht6A8uLstpQIXyj
    template-haskell-2.11.0.0 temporary-1.2.0.4-2ZGJgvUMoC3CqxertnjRxn
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    transformers-0.5.2.0 transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/ghc-mod/html/ghc-mod.haddock
haddock-html: /usr/share/doc/ghc-mod/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-mod-5.7.0.0-33-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ghc-mod.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ghc-mod
version: 5.7.0.0
id: ghc-mod-5.7.0.0-iOcm9YAMrJDxJ7diBuPNO
key: ghc-mod-5.7.0.0-iOcm9YAMrJDxJ7diBuPNO
license: AGPL-3
maintainer: Daniel Gröber <dxld@darkboxed.org>
homepage: http://www.mew.org/~kazu/proj/ghc-mod/
synopsis: Happy Haskell Programming
description:
    ghc-mod is a backend program to enrich Haskell programming in editors. It
    strives to offer most of the features one has come to expect from modern IDEs
    in any editor.
    ghc-mod provides a library for other haskell programs to use as well as a
    standalone program for easy editor integration. All of the fundamental
    functionality of the frontend program can be accessed through the library
    however many implementation details are hidden and if you want to
    significantly extend ghc-mod you should submit these changes upstream instead
    of implementing them on top of the library.
    For more information, please see its home page.
category: GHC, Development
author: Kazu Yamamoto <kazu@iij.ad.jp>,
        Daniel Gröber <dxld@darkboxed.org>,
        Alejandro Serrano <trupill@gmail.com>,
        Nikolay Yakimov <root@livid.pp.ru>
exposed: True
exposed-modules:
    Language.Haskell.GhcMod Language.Haskell.GhcMod.Internal
    Language.Haskell.GhcMod.Boot Language.Haskell.GhcMod.Browse
    Language.Haskell.GhcMod.CabalHelper Language.Haskell.GhcMod.Caching
    Language.Haskell.GhcMod.Caching.Types
    Language.Haskell.GhcMod.CaseSplit Language.Haskell.GhcMod.Check
    Language.Haskell.GhcMod.Convert Language.Haskell.GhcMod.Cradle
    Language.Haskell.GhcMod.CustomPackageDb
    Language.Haskell.GhcMod.Debug Language.Haskell.GhcMod.DebugLogger
    Language.Haskell.GhcMod.Doc Language.Haskell.GhcMod.DynFlags
    Language.Haskell.GhcMod.DynFlagsTH Language.Haskell.GhcMod.Error
    Language.Haskell.GhcMod.FileMapping Language.Haskell.GhcMod.FillSig
    Language.Haskell.GhcMod.Find Language.Haskell.GhcMod.Flag
    Language.Haskell.GhcMod.Gap Language.Haskell.GhcMod.GhcPkg
    Language.Haskell.GhcMod.HomeModuleGraph
    Language.Haskell.GhcMod.Info Language.Haskell.GhcMod.Lang
    Language.Haskell.GhcMod.Lint Language.Haskell.GhcMod.LightGhc
    Language.Haskell.GhcMod.Logger Language.Haskell.GhcMod.Logging
    Language.Haskell.GhcMod.Modules Language.Haskell.GhcMod.Monad
    Language.Haskell.GhcMod.Monad.Env Language.Haskell.GhcMod.Monad.Log
    Language.Haskell.GhcMod.Monad.Newtypes
    Language.Haskell.GhcMod.Monad.Orphans
    Language.Haskell.GhcMod.Monad.Out
    Language.Haskell.GhcMod.Monad.State
    Language.Haskell.GhcMod.Monad.Types Language.Haskell.GhcMod.Output
    Language.Haskell.GhcMod.PathsAndFiles
    Language.Haskell.GhcMod.PkgDoc Language.Haskell.GhcMod.Pretty
    Language.Haskell.GhcMod.Read Language.Haskell.GhcMod.SrcUtils
    Language.Haskell.GhcMod.Stack Language.Haskell.GhcMod.Target
    Language.Haskell.GhcMod.Test Language.Haskell.GhcMod.Types
    Language.Haskell.GhcMod.Utils Language.Haskell.GhcMod.World
    Language.Haskell.GhcMod.Options.Options
    Language.Haskell.GhcMod.Options.DocUtils
    Language.Haskell.GhcMod.Options.Help
hidden-modules: Paths_ghc_mod Utils Data.Binary.Generic
                System.Directory.ModTime
abi: 3199ebc3c847039253e61566c743e522
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/ghc-mod-5.7.0.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/ghc-mod-5.7.0.0
data-dir: /usr/share/ghc-mod
hs-libraries: HSghc-mod-5.7.0.0-iOcm9YAMrJDxJ7diBuPNO
depends:
    base-4.9.0.0 binary-0.8.3.0 bytestring-0.10.8.1
    cabal-helper-0.7.3.0-8irtsA9yeTTAn5BCqOpvck containers-0.5.7.1
    deepseq-1.4.2.0 directory-1.2.6.2
    djinn-ghc-0.0.2.3-JYPrGjYjGTkHuXWB4dLmHD
    extra-1.5.2-FWjov7JFxoq2wD5IPaMEgG
    fclabels-2.0.3.2-3Xs3bCBbAC9J1XqCJSoYEp filepath-1.4.1.0 ghc-8.0.1
    ghc-boot-8.0.1 ghc-paths-0.1.0.9-GIOnKzk0HmEBZ77Q1HsThK
    ghc-syb-utils-0.2.3-8FwTENlrnJNLAYazvnOvfZ
    haskell-src-exts-1.18.2-HPJDx1bP0PTGB2XZpVQJ3s
    hlint-1.9.41-ApEZWaSgjF4FM2lyN1LFSd
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    monad-journal-0.7.2-LdzJ97MJz5972dk8ynYKRG
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    old-time-1.1.0.3-IcvdkJUsE9M8t3io8peAEp
    optparse-applicative-0.13.2.0-2f8ecj6rdMuFtm9J78ebBE
    pipes-4.3.4-BvSd4URf0wlE2GikyprOR6 pretty-1.1.3.3 process-1.4.2.0
    safe-0.3.14-ALdwhNEer7fKnF5VYCbXfH
    split-0.2.3.2-1dCEe3bkR6E9uyZt6jsXK syb-0.6-C65vWCsht6A8uLstpQIXyj
    template-haskell-2.11.0.0 temporary-1.2.0.4-2ZGJgvUMoC3CqxertnjRxn
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v time-1.6.0.1
    transformers-0.5.2.0 transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/ghc-mod/html/ghc-mod.haddock
haddock-html: /usr/share/doc/ghc-mod/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
